/*
 * Copyright (c) 1996, 2003 VIA Networking Technologies, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *    This product includes software developed by VIA Networking Technologies, Inc.
 * 4. Neither the name of the Company nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY VIA NETWORKING TECHNOLOGIES, INC. AND
 * CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
 * BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL
 * VIA NETWORKING TECHNOLOGIES, INC. OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *
 * File: if_getb_cfg.h
 *
 * Purpose: Driver configuration header file
 *
 * Author: Ryan Fu
 *
 * Date: Jul 22, 2003
 *
 *
 */

#ifndef __IF_GETB_CFG_H__
#define __IF_GETB_CFG_H__

/*
 *  Options for driver
 */
#define TX_DESC_NUM_DEF     (64)
/* TX_DESC_NUM_DEF is used for setting number of Tx descriptors.
   range: 16-256
   default: 64
*/

#define RX_DESC_NUM_DEF     (64)
/* RX_DESC_NUM_DEF is used for setting number of Rx descriptors.
   This value must be 4X.
   range: 64-255
   default: 64
*/

#define SPEED_DUPLEX_DEF    (0)
/* SPEED_DUPLEX_DEF is used for setting the speed and duplex mode of NIC.
   0: indicate autonegotiation for both speed and duplex mode
   1: indicate 100Mbps half duplex mode
   2: indicate 100Mbps full duplex mode
   3: indicate 10Mbps half duplex mode
   4: indicate 10Mbps full duplex mode
*/

#define DMA_LENGTH_DEF      (1)
/* DMA_LENGTH_DEF is used for controlling the DMA length
   0: 8 DWORDs
   1: 16 DWORDs
   2: 32 DWORDs
   3: 64 DWORDs
   4: 128 DWORDs
   5: 256 DWORDs
   6: SF(flush till emply)
   7: SF(flush till emply)
*/

#define RX_THRESH_DEF       (0)
/* RX_THRESH_DEF is used for controlling the receive fifo threshold.
   0: indicate the rxfifo threshold is 128 bytes.
   1: indicate the rxfifo threshold is 512 bytes.
   2: indicate the rxfifo threshold is 1024 bytes.
   3: indicate the rxfifo threshold is store & forward.
*/

#define FLOW_CNTL_DEF       (1)
/* FLOW_CNTL_DEF is used for setting the flow control ability of NIC.
   1: hardware deafult - AUTO (default). Use Hardware default value in ANAR.
   2: enable TX flow control.
   3: enable RX flow control.
   4: enable RX/TX flow control.
   5: disable
*/

#define VAL_PKTLEN_DEF      (0)
/* VAL_PKTLEN_DEF is used for setting the option of dropping invalid length 802.3 frame.
   0: Receive frame with invalid layer 2 length (Default)
   1: Drop frame with invalid layer 2 length
*/

#define HWCSUM_OFFLOAD      (1)
/* HWCSUM_OFFLOAD is used for enabling rx/tx checksum offload ability of NIC.
   This option is supported after FreeBSD 4.0.
   0: Disable
   1: Enable (Default)
*/

#define VLAN_TAGGING        (0)
/* VLAN_TAGGING is used for enabling 802.1Q VID tagging ability of NIC.
   This option is supported after FreeBSD 5.0.
   0: Disable VID setting (Default)
   1: Enable VID setting
*/

#define GETB_NAME           "if_getb"
#define GETB_FULL_DRV_NAM   "VIA Networking Velocity Family Gigabit Ethernet Adapter Driver"
#define GETB_ADAPTER_NAM    "VIA Networking Velocity Family Gigabit Ethernet Adapter"

#ifndef MAJOR_VERSION
#define MAJOR_VERSION       1
#endif

#ifndef MINOR_VERSION
#define MINOR_VERSION       20
#endif

#ifndef GETB_VERSION
#define GETB_VERSION        "1.20"
#endif

#define RX_BUF_SIZE_DEFAULT (2*1024)



#define KFREE(x)            kfree((x))

#define MAX_UINTS           8
#define OPTION_DEFAULT      { [0 ... MAX_UINTS-1] = -1}

#define REV_ID_VT6110       (0)
#define DEVICE_ID_VT6110    (0x3119)
#define VIA_VENDOR_ID       (0x1106)
#define PCI_ANY_ID          (0xFFFF)


#define VAR_USED(p)     do { (p)=(p); } while (0)

/* for BSD version compatibility */
#if __FreeBSD_version >= 500000
#define IFM_1000_TX       IFM_1000_T
#endif


#endif /* __IF_GETB_CFG_H__ */
